<!DOCTYPE HTML>
<html lang="en">
<head>
	<meta charset="UTF-8">
	<title></title>
	<link rel="stylesheet" href="style.css" />
</head>
<body>
	{{#links}}
		<a href="{{link}}.html">{{link}}</a>
	{{/links}}
</body>
</html>
